#!/usr/bin/env node
import inquirer from "inquirer";
import path from "path";
import fs from "fs-extra";
import chalk from "chalk";
import { initializeGit } from "./utils/git.js";
import { copyTemplateFiles } from "./utils/templates.js";
async function promptUser() {
    try {
        console.log(chalk.blue("Starting project configuration..."));
        const answers = await inquirer.prompt([
            {
                type: "input",
                name: "projectName",
                message: "What is your project name?",
                validate: (input) => {
                    if (/^[a-zA-Z0-9-_]+$/.test(input))
                        return true;
                    return "Project name may only include letters, numbers, dashes and underscores";
                },
            },
            {
                type: "list",
                name: "projectType",
                message: "What type of project would you like to create?",
                choices: [
                    { name: "Backend (Node.js + TypeScript)", value: "backend" },
                    { name: "Frontend (React + TypeScript)", value: "frontend" },
                    { name: "Full-stack (Combined setup)", value: "fullstack" },
                ],
            },
        ]);
        console.log(chalk.green("Configuration completed successfully"));
        return answers;
    }
    catch (error) {
        console.error(chalk.red("Error during project configuration:"), error);
        throw error;
    }
}
async function createProject(config) {
    const projectPath = path.join(process.cwd(), config.projectName);
    console.log(chalk.blue(`\nCreating new ${config.projectType} project: ${config.projectName}`));
    try {
        if (await fs.pathExists(projectPath)) {
            throw new Error(`Directory ${config.projectName} already exists`);
        }
        await fs.mkdir(projectPath);
        console.log(chalk.green("Project directory created"));
        await copyTemplateFiles(config, projectPath);
        console.log(chalk.green("Template files copied"));
        await initializeGit(projectPath);
        console.log(chalk.green("Git repository initialized"));
        console.log(chalk.green("\nProject created successfully!"));
        console.log(chalk.yellow("\nNext steps:"));
        console.log(`1. cd ${config.projectName}`);
        console.log("2. yarn install");
        console.log("3. yarn start");
    }
    catch (error) {
        console.error(chalk.red("Error creating project:"), error);
        // Clean up if directory was created
        if (await fs.pathExists(projectPath)) {
            await fs.remove(projectPath);
        }
        throw error;
    }
}
async function main() {
    console.log(chalk.blue("Bootstrap TypeScript App CLI"));
    try {
        const config = await promptUser();
        await createProject(config);
    }
    catch (error) {
        console.error(chalk.red("Fatal error:"), error);
        process.exit(1);
    }
}
main().catch((error) => {
    console.error(chalk.red("Unexpected error:"), error);
    process.exit(1);
});
//# sourceMappingURL=index.js.map